@@ -72,7 +72,7 @@ sub new {
     bless $self, $class;
     confess( __PACKAGE__, " new : ", join( " ", @$missing ), " keys with values missing" ) if ( defined( $missing = $self->_get_missing_arg( \%arg, [qw(cols dman)] ) ) );
     $self->{log} = Log::Log4perl->get_logger(__PACKAGE__);
-    $self->{log}->debug("new called");
+    $self->{log}->debug("new called ** cols are ", join(" ", @{ $self->{cols}}) );
     my %hcols = map { $_ => 1 } @{ $self->{cols} };
     $self->{hcols} = \%hcols;
     return $self;
@@ -89,6 +89,12 @@ sub _has_more_row {
 sub _get_val {
     my $self = shift;
     my ( $row, $col, $name ) = @_;
+    $self->{log}->debug("_get_val \$name: ", (defined $name ? $name : "undef"));
+    #wx grid : $col is -1 without a corresponding name
+    #so the call to colnumber_from_name fails
+    #return undef for db columns (from @cols) not in the @fields list
+    #return unless defined $self->colnumber_from_name($name);
+    confess ("col number undef") unless defined $col;
     $self->{log}->debug( "_get_val \n", Dumper $row);
     $self->{get_val}->( $row, $col, $name );
 
@@ -202,6 +208,18 @@ sub get_gui_type {
 	$fieldtype{ $dbtype };
 }
 
+=head2 get_grid_fields
+
+Return the names of the columns passed in the fields arg
+
+=cut
+
+sub get_grid_fields {
+    my $self = shift;
+    return keys %{$self->{colname_to_number}};
+
+}
+
 =head2 colnumber_from_name
 
 Return the column position (0 based)
@@ -210,7 +228,6 @@ Param: the name of the column.
 
 =cut
 
-
 sub colnumber_from_name {
 
     my ( $self, $fieldname ) = @_;
@@ -242,12 +259,16 @@ sub apply {
         %seen = map { $_ => $seen{$_}++ } ( @{ $self->{cols} }, @{$pkref} );
         @fields_to_save = grep { $seen{$_} < 1 } keys %seen;
     } else {
-        @fields_to_save = @{ $self->{cols} };
+        # bug here ? since $self->cols holds field name from the tables that 
+        # could not be in the grid 
+        # @fields_to_save = @{ $self->{cols} };
+        @fields_to_save = $self->get_grid_fields;
+        $self->{log}->debug("grid_fields ", join(" ", @fields_to_save));
     }
     $self->{sig_block}->( $self->{sig} ) if ( $self->{sig} );
     while ( $self->_has_more_row ) {
         my $status = $self->_get_val( $self->_get_row, $self->{status_col} );
-        $self->{log}->debug( "status ", $status );
+        $self->{log}->debug( "status ", ( defined $status ? $status : " undef") );
         $self->{dman}->set_row_pos( $self->{curr_row} );
         if ( $status == UNCHANGED || $status == LOCKED ) {
             $self->{log}->debug("move to next row without saving");
@@ -282,7 +303,7 @@ sub apply {
 
                     # $model->get( $iter, $self->{colname_to_number}->{$name} );
                     $count_update++;
-                    $self->{log}->debug( "Set dman field: " . $name . " col_pos " . $col . " row_pos " . $self->{curr_row} . " value: " . ( $x ? $x : "undef" ) );
+                    $self->{log}->debug( "Set dman field: " . $name . " col_pos " . $col . " row_pos " . $self->{curr_row} . " value: " . ( defined  $x ? $x : "undef" ) );
                     $self->{dman}->set_field( $name, $x );
 
                 } else {
@@ -331,7 +352,7 @@ sub apply {
 
 =head2 setup_fields
 
-Must be called after new, to build the colname_to_number hash used by colnumber_from_name.
+Must be called after new, to build the colname_to_number hash used by colnumber_from_name and by get_grid_fields.
 Return an array ref of hash ref defining the fields of the grid + an array ref of the names of the columns of the underlying table.
 
 Parameters
@@ -340,7 +361,8 @@ Parameters
 
 =item allfields 
 
-A reference to an array of hash ref received in the constructor of the datasheet object. This array ref is returned completed with the 
+A reference to an array of hash ref received in the constructor of the datasheet object holding the fields used in the grid. 
+This array ref is returned completed with the render
 
 =item cols
 
@@ -356,7 +378,7 @@ sub setup_fields {
 	my $self = shift;
 	my %args =  ( ref $_[0] eq "HASH" ? %$_[0] : (@_) );
 	my $missing;
-	 confess( __PACKAGE__, " init_combo_setup : ", join( " ", @$missing ), " keys with value missing" ) if ( defined( $missing = $self->_get_missing_arg( \%args, [qw(allfields cols )] ) ) );
+	 confess( __PACKAGE__, "setup_fields : ", join( " ", @$missing ), " keys with value missing" ) if ( defined( $missing = $self->_get_missing_arg( \%args, [qw(allfields cols )] ) ) );
 	my $fields = $args{allfields};
 
 	    if ( !$fields ) {
@@ -380,6 +402,7 @@ sub setup_fields {
     if ($args{status_col}){
     
         # Gtk2::Ex::DbLinker::Datasheet Put a _status_column_ at the front of $self->{fields}
+         $self->{log}->debug("add ", $args{status_col}, " on top of \@{ \$fields }");
         unshift @{ $fields }, $args{status_col};
 
     } #if
@@ -415,7 +438,7 @@ sub setup_fields {
     }
 
 $self->{colname_to_number} = \%name2pos;
-$self->{log}->debug(Dumper %{$self->{colname_to_number}});
+$self->{log}->debug("setup_fields colname_to_number hash:", Dumper %{$self->{colname_to_number}});
 return ( $fields, \@hiddencols);
 
 
