@@ -93,7 +93,7 @@ sub set_row_pos {
     if ( !defined( $self->{row}->{pos} ) ) {
         $self->{log}->debug("no data");
         $found = 0;
-    } elsif ( $pos < $self->{row}->{last_row} + 1 && $pos >= 0 ) {
+    } elsif ( defined $self->{row}->{last_row} && ($pos < $self->{row}->{last_row} + 1 && $pos >= 0 )) {
 	    # $self->{log}->debug( "setting current row to an existing row at pos ", $pos );
         $self->{row}->{pos} = $pos;
 
@@ -134,7 +134,7 @@ sub set_row_pos {
             $self->{current_row} = $r;
         }    # else current_row remains the same
 
-    } elsif ( $pos == $self->{row}->{last_row} + 1 ) {
+    } elsif ( defined $self->{row}->{last_row} && $pos == $self->{row}->{last_row} + 1 ) {
 
         #$self->{log}->debug("setting current row to undef");
         #$self->{current_row} = undef;
@@ -222,11 +222,19 @@ sub save {
         $row = $self->{new_row};
 
         #$row->update;
-        $done = ( defined $row->insert ? 1 : 0 );
+        my $new_row =  $row->insert;
+        $done = ( defined $new_row ? 1 : 0 );
+        #$self->{rs}->create($row->insert);
         $self->{log}->debug( " insert return " . $done );
+        $self->{log}->debug("rs->count : ", $self->{rs}->count); #return 0 even insert has been called
+        #with the abo-jrnabt example the where clause is noabt < 0 -> the form is empy
+        #but this filter is still added with insert so the count is still 0
+        #
+        # $self->{row}->{last_row} +=  1; not needed if count is taken from the nuber of rows in $self->{data}
+        $self->{current_row} = $new_row;
         my @pk_val;
-        for my $pk ( $row->primary_columns ) {
-            my $pkval = $row->get_column($pk);
+        for my $pk ( $new_row->primary_columns ) {
+            my $pkval = $new_row->get_column($pk);
             $self->{log}->debug( "pk after insert: " . $pkval );
             push @pk_val, $pkval;
         }
@@ -236,10 +244,12 @@ sub save {
         }
         push @{ $self->{data} }, \@pk_val;
 
-        # setting the cursor on the newly added row is done in Form->apply
-        #my $last = $self->row_count-1;
-        # my $last = scalar (@{$self->{data}}) -1;
-        #$self->{log}->debug("last after saved new row: ", $last);
+        #calling new_row  in Form->apply sets the cursor on the newly added row 
+        #and increment the last_row by 1
+        #
+        
+        #my $last = scalar (@{$self->{data}}) -1;
+        $self->{log}->debug("row_count after saved new row: ", $self->row_count);
         #$self->{row} = {pos => $last, last_row => $last};
         # $self->set_row_pos($last);
 
@@ -290,11 +300,16 @@ sub new_row {
         }
 
     }
+    $self->{log}->debug("new_row  last_row : ", (defined $self->{row}->{last_row} ? $self->{row}->{last_row} : " undef"));
 
     #row->insert is done in save
     my $row = $rs->new_result( \%hash );
     $self->{new_row} = $row;
-
+    $self->{log}->debug("new_row sets to rs->new_result rs->count is ", $self->{rs}->count);
+    #rs->count is not changed until rs->insert is called
+    #so row->count is wrong at this time
+    #
+    #
     #to insure that the new row is at last + 1:
     if ( defined $self->{row}->{last_row} ) {
         $self->{row}->{pos} = $self->{row}->{last_row} + 1;
@@ -305,7 +320,7 @@ sub new_row {
 
     $self->{log}->debug(
         "new_row pos:", $self->{row}->{pos},
-        " last: ",      $self->{row}->{last}
+        " last: ",      $self->{row}->{last_row}
     );
 
     #$self->{log}->debug( Dumper($row));
@@ -357,14 +372,17 @@ sub row_count {
     my $self = shift;
     my $hr   = $self->{row};
 
-    #my $count = scalar @{$self->{data}};
+    my $count = scalar @{$self->{data}};
     #data is updated only after a call to query
     #the resultset->count takes into account a change in the row's selection
-    my $count = $self->{rs}->count;
-    $self->{log}->debug( "row_count last pos : "
-          . ( defined $hr->{last_row} ? $hr->{last_row} : -1 )
-          . " count: "
-          . $count );
+    #but new rows added to an empty resultset (pk < 0) are not counted when rs->insert is called
+    #rs->count is still 0
+    #since the filter pk < 0 is still applied
+    #my $count = $self->{rs}->count;
+    $hr->{last_row}= $count -1;
+    $self->{log}->debug( "row_count last pos : ",
+           ( defined $hr->{last_row} ? $hr->{last_row} : "undefined" ),
+           " count: ", $count );
     return $count;
 
 }
@@ -419,18 +437,20 @@ sub _init_pos {
     $self->{data} = \@data;
 
     #$self->{data}= \@pks;
-
+    #
     my $count = scalar @{ $self->{data} };
 
     if ( $count > 0 ) {
 
         $self->{row} = { pos => 0, last_row => $count - 1 };
     } else {
+        $self->{log}->debug("_init_pos setting pos and last_row to undef");
         $self->{row} = { pos => undef, last_row => undef };
     }
-
 }
 
+
+
 sub _init {
     my $self  = shift;
     my $rs    = $self->{rs};
@@ -496,6 +516,7 @@ sub _init {
 
 }
 
+
 sub _move {
     my ( $self, $offset, $absolute ) = @_;
     $self->{log}->debug( "move offset: "
