@@ -30,7 +30,7 @@ sub new {
 
     };
     $self->{log} =
-      Log::Log4perl->get_logger("Gtk2::Ex::DbLinker::RdbDataManager");
+        Log::Log4perl->get_logger("Gtk2::Ex::DbLinker::RdbDataManager");
 
     $self->{rocols} = [];
     bless $self, $class;
@@ -52,7 +52,7 @@ sub query {
     $self->_init if ( @{ $self->{cols} } == 0 );
     $self->set_row_pos( $self->{row}->{pos} );
 
-    # $self->{log}->debug("query : " . @$data[0]->noti ) if (scalar @$data > 0);
+  # $self->{log}->debug("query : " . @$data[0]->noti ) if (scalar @$data > 0);
     foreach my $r ( @{ $self->{data} } ) {
         foreach my $f ( @{ $self->{cols} } ) {
             $self->{log}->debug( $f . " : " . ( $r->{$f} ? $r->{$f} : "" ) );
@@ -70,16 +70,18 @@ sub set_row_pos {
     if ( !defined( $self->{row}->{pos} ) ) {
         $self->{log}->debug("RdbDataManager : not data");
         $found = 0;
-    } elsif ( $pos <= $self->{row}->{last_row} + 1 && $pos >= 0 ) {
+    }
+    elsif ( $pos <= $self->{row}->{last_row} + 1 && $pos >= 0 ) {
         $self->{row}->{pos} =
-          $pos;    #if pos is last_row + 1 we are inserting a new row
-                   #this row is created with new_row
-                   #this row will be pushed on the row array on save
-                   #and saved to the database with row->save
-                   #} elsif ($pos == $self->{row}->{last_row} + 1) {
-                   #	$self->{row}->{pos} =  $pos;
+            $pos;    #if pos is last_row + 1 we are inserting a new row
+                     #this row is created with new_row
+                     #this row will be pushed on the row array on save
+                     #and saved to the database with row->save
+                     #} elsif ($pos == $self->{row}->{last_row} + 1) {
+                     #	$self->{row}->{pos} =  $pos;
 
-    } else {
+    }
+    else {
         $found = 0;
         croak(" position outside rows limits ");
     }
@@ -108,21 +110,44 @@ sub set_field {
 
     #if ($key ~~ @{$self->{rocols}}){
     if ( grep( /^$key$/, @{ $self->{rocols} } ) ) {
-        $self->{log}->debug( "set_field: " . $id . " key: " . $key . " pos: " . $pos . " skipped since this is a readonly field." );
-    } elsif (grep( /^$key$/, @{ $self->{ai_primary_keys} } )) {
-	$self->{log}->debug( "set_field: " . $id . " key: " . $key . " pos: " . $pos . " skipped since this is an ai primary key." );
-    } else {
-        $self->{log}->debug( "set_field: " . $id . " key: " . $key . " pos: ". $pos . " value : " . ( $value ? $value : "" ) );
+        $self->{log}->debug( "set_field: "
+                . $id
+                . " key: "
+                . $key
+                . " pos: "
+                . $pos
+                . " skipped since this is a readonly field." );
+    }
+    elsif ( grep( /^$key$/, @{ $self->{ai_primary_keys} } ) ) {
+        $self->{log}->debug( "set_field: "
+                . $id
+                . " key: "
+                . $key
+                . " pos: "
+                . $pos
+                . " skipped since this is an ai primary key." );
+    }
+    else {
+        $self->{log}->debug( "set_field: "
+                . $id
+                . " key: "
+                . $key
+                . " pos: "
+                . $pos
+                . " value : "
+                . ( $value ? $value : "" ) );
         if ( $pos >= $self->row_count ) {
             $row = $self->{new_row};
-        } else {
+        }
+        else {
             $row = $self->{data}[$pos];
         }
         my $rel = $self->{fieldsRel}->{$key};
         my $m   = $self->{fieldSetter}->{$key};
         if ($rel) {
             $row->{$rel}->$m($value);
-        } else {
+        }
+        else {
             $row->$m($value);
         }
     }
@@ -130,16 +155,21 @@ sub set_field {
 
 sub get_field {
     my ( $self, $id ) = @_;
-    my $pos  = $self->{row}->{pos};
-    return unless defined $pos; #prevents cascade of errors when get_field is called on inexisting row
+    my $pos = $self->{row}->{pos};
+    return
+        unless defined $pos
+        ; #prevents cascade of errors when get_field is called on inexisting row
     my $last = $self->row_count;
+
     #$self->{log}->debug( "get_field: pos ", $pos, " last : ", $last );
     my $row;
     if ( $pos < $last ) {
         $row = $self->{data}[$pos];
-    } elsif ( $pos == $last ) {
+    }
+    elsif ( $pos == $last ) {
         $row = $self->{new_row};
-    } else {
+    }
+    else {
         $self->{log}->debug("current pos outside row limits");
     }
     if ( $self->{isalias}->{$id} ) {
@@ -149,16 +179,17 @@ sub get_field {
     $rel = ( $rel ? $rel : "" );
     my $key = $rel . $id;
     my $m   = $self->{fieldGetter}->{$key};
-
     my $v;
-    if ( length($rel) ) {
-	 # $self->{log}->debug( "get_field " . $id . " rel: " . $rel . " method: " . $m );
-        $v = $row->{$rel}->$m()
-          ; # or croak(__PACKAGE__ . "1 no method found to get value from the column " . $rel . " + " . $id);
-    } else {
-	#$self->{log}->debug( "get_field " . $id  . " method: " . ( defined $m ? $m : " undefined" ) );
-        $v = $row->$m()
-          ; # or croak(__PACKAGE__ . " no method found to get value from the column " . $id);
+    if ( defined $m ) {
+        if ( length($rel) ) {
+            $v = $row->{$rel}->$m();
+        }
+        else {
+            $v = $row->$m();
+        }
+    }
+    else {
+        $self->{log}->debug( "field ", $id, " undefined" );
     }
     return $v;
 
@@ -168,19 +199,20 @@ sub save {
     my $self = shift;
     my $row;
     if ( $self->{new_row} ) {
-        $self->{log}->debug(__PACKAGE__," save new row ");
+        $self->{log}->debug( __PACKAGE__, " save new row " );
         $row = $self->{new_row};
         push @{ $self->{data} }, $row;
         my $last = $self->row_count - 1;
         $self->{row} = { pos => $last, last_row => $last };
 
-    } else {
-        $self->{log}
-          ->debug( __PACKAGE__," save at " . $self->{row}->{pos} );
+    }
+    else {
+        $self->{log}->debug( __PACKAGE__, " save at " . $self->{row}->{pos} );
         my $pos = $self->{row}->{pos};
         $row = $self->{data}[$pos];
     }
     $self->{log}->debug("saving and unsetting new row");
+
 =for comment
      my $m = $row->meta();
      my @col = $m->columns;
@@ -189,6 +221,7 @@ sub save {
  	$self->{log}->debug("name: ", $c->name, " type ", $c->type);
       }
 =cut
+
     my $done;
     $done = $row->save or carp("can't save ...\n");
     $self->{new_row} = undef;
@@ -212,7 +245,7 @@ sub new_row {
 sub delete {
     my $self = shift;
     $self->{log}
-      ->debug( "Linker::RdbDataManager delete at " . $self->{row}->{pos} );
+        ->debug( "Linker::RdbDataManager delete at " . $self->{row}->{pos} );
     my $pos = $self->{row}->{pos};
     if ( defined $pos ) {    # if ($pos) is false when $pos is 0
         my $row = $self->{data}[$pos];
@@ -221,7 +254,8 @@ sub delete {
         splice @{ $self->{data} }, $pos, 1;
         if ( $self->row_count == 0 ) {
             $self->{row} = { pos => undef, last_row => undef };
-        } else {
+        }
+        else {
             $self->next;
             $self->{row} = { pos => $pos, last_row => $self->row_count - 1 };
         }
@@ -253,7 +287,8 @@ sub row_count {
     my $self  = shift;
     my $hr    = $self->{row};
     my $count = scalar @{ $self->{data} };
-    # $self->{log}->debug( "row_count last pos : ". ( $hr->{last_row} ? $hr->{last_row} : -1 ). " count: ". $count );
+
+# $self->{log}->debug( "row_count last pos : ". ( $hr->{last_row} ? $hr->{last_row} : -1 ). " count: ". $count );
     return $count;
 
 }
@@ -298,17 +333,19 @@ sub _init_fields_access {
     my $aref = ( $fldref ? $fldref : $meta->column_names );
     $relname = ( $relname ? $relname : "" );
     $self->{log}
-      ->debug( "init_fields_access: fields are " . join( " ", @$aref ) );
+        ->debug( "init_fields_access: fields are " . join( " ", @$aref ) );
     foreach my $id (@$aref) {
         my $c = $meta->column($id);
         croak("Field $id not found in $meta->class metadata") unless ($c);
         my $method = $c->method_name('get') || $c->method_name('get_set')
-          or croak("no get/get_set method found for $id");
+            or croak("no get/get_set method found for $id");
         $self->{fieldGetter}->{ $relname . $id } = $method;
-        $self->{log}->debug(
-            "get method for field " . $relname . " " . $id . " : " . $method );
+        $self->{log}->debug( "get method for field "
+                . $relname . " "
+                . $id . " : "
+                . $method );
         $method = $c->method_name('set') || $c->method_name('get_set')
-          or croak("no set/get_set method found for $id");
+            or croak("no set/get_set method found for $id");
         $self->{fieldSetter}->{ $relname . $id }  = $method;
         $self->{fieldsDBType}->{ $relname . $id } = $c->type;
 
@@ -326,12 +363,12 @@ sub _init_joined_fields {
         my $aref = $h{$relname};
         my @a = map { $relname . $_ } @$aref;
         push @{ $self->{cols} }, @$aref
-          ; #widget's name are given without a table's or relationship's name in the glade file
-        $self->{log}
-          ->debug( "init_joined_fields: fields are " . join( " ", @$aref ) );
+            ; #widget's name are given without a table's or relationship's name in the glade file
+        $self->{log}->debug(
+            "init_joined_fields: fields are " . join( " ", @$aref ) );
         push @{ $self->{rocols} }, @a;
         $self->{log}
-          ->debug( "init_joined_fields: ro_fields are " . join( " ", @a ) );
+            ->debug( "init_joined_fields: ro_fields are " . join( " ", @a ) );
         my $class = $self->{meta}->relationship($relname)->{class};
         $self->{log}->debug( "class: ", $class );
         my $meta = Rose::DB::Object::Metadata->for_class($class);
@@ -347,7 +384,8 @@ sub _init_pos {
     if ($first) {
         my $count = scalar @{ $self->{data} };
         $self->{row} = { pos => 0, last_row => $count - 1 };
-    } else {
+    }
+    else {
         $self->{row} = { pos => undef, last_row => undef };
     }
 
@@ -378,7 +416,7 @@ sub _init {
         $self->{primary_keys}    = \@pk  unless ( $self->{primary_keys} );
         $self->{ai_primary_keys} = \@apk unless ( $self->{ai_primary_keys} );
         $self->{log}
-          ->debug( "Rdb_dman_init: field " . $id . " type: " . $c->type );
+            ->debug( "Rdb_dman_init: field " . $id . " type: " . $c->type );
     }
     if ( defined $self->{alias} ) {
         my %usedfor;
@@ -405,7 +443,9 @@ sub _init {
         push @{ $self->{cols} }, $meta->column_names;
         $self->_init_fields_access( $meta, undef, undef );
 
-    } else { #use meta object from the relationship objects, not from the main table
+    }
+    else
+    {  #use meta object from the relationship objects, not from the main table
          #the pk field has been defined above from the meta data from the main table
         $self->_init_joined_fields( $self->{columns} );
     }
@@ -414,19 +454,21 @@ sub _init {
 sub _move {
     my ( $self, $offset, $absolute ) = @_;
     $self->{log}->debug( "move offset: "
-          . ( $offset ? $offset : "" )
-          . " abs: "
-          . ( defined $absolute ? $absolute : "" ) );
+            . ( $offset ? $offset : "" )
+            . " abs: "
+            . ( defined $absolute ? $absolute : "" ) );
     if ( defined $absolute ) {
         $self->{row}->{pos} = $absolute;
-    } else {
+    }
+    else {
         $self->{row}->{pos} += $offset;
     }
 
     # Make sure we loop around the recordset if we go out of bounds.
     if ( $self->{row}->{pos} < 0 ) {
         $self->{row}->{pos} = 0;
-    } elsif ( $self->{row}->{pos} > $self->row_count() - 1 ) {
+    }
+    elsif ( $self->{row}->{pos} > $self->row_count() - 1 ) {
         $self->{row}->{pos} = $self->row_count() - 1;
     }
     return $self->{row}->{pos};
