@@ -129,6 +129,12 @@ sub new {
             $self->query( { -where => $self->{select_param}->{-where} } );
 
         }
+
+        if ( $self->{select_param}->{-having} ) {
+            #$self->{log}->debug("query called without arg");
+            $self->query();
+        
+        }
     }
 
     return $self;
@@ -146,15 +152,19 @@ sub query {
     #my ( $self,  $where ) = @_;
     my $self = shift;
     my %h;
-    my $where = ( ref $_[0] eq "HASH" ) ? $_[0] : ( %h = (@_) ) && \%h;
+   
     my $select = $self->{select_param};
     my $col    = $select->{-columns};     #could be undef, default to '*'
          #my $worig = $self->{select_param}->{-where};
-    $select->{-where} = $where->{-where};
+     my $where;
+     if ( defined $_[0]) {
+         $where = ( ref $_[0] eq "HASH" ) ? $_[0] : ( %h = (@_) ) && \%h;
+        $select->{-where} = $where->{-where} if ( exists $where->{-where} );
+    }
 
     #$self->{select_param} = $select;
 
-    #$self->{log}->debug("query: ", Dumper($select));
+    $self->{log}->debug("query: ", Dumper($select));
 
     if ( $self->{before_query} ) {
         $self->{before_query}();
@@ -500,7 +510,7 @@ sub delete {
 
 sub _execute {
     my ( $self, $sql, @bind ) = @_;
-    #$self->{log}->debug( "_execute:", $sql );
+    # $self->{log}->debug( "_execute:", $sql );
     my $sth = $self->{dbh}->prepare($sql);
 
     #my $done=0;
